@@ -1,9 +1,10 @@
-from django.contrib.auth.models import User
+from django.contrib.auth import get_user_model
 from django.conf import settings
 from rest_framework import authentication
 
 from netaddr import IPAddress
 
+User = get_user_model()
 
 class ApiKeyAuthentication(authentication.BaseAuthentication):
     def authenticate(self, request):
