@@ -1,12 +1,13 @@
 from urllib.parse import urljoin
 from rest_framework import authentication
-from django.contrib.auth.models import User
+from django.contrib.auth import get_user_model
 from django.conf import settings
 from rest_framework import exceptions
 import logging
 import requests
 
 
+User = get_user_model()
 logger = logging.getLogger(__name__)
 
 
